round_pipeline_verilog

Function round_pipeline_verilog 

pub fn round_pipeline_verilog<const ROUNDS: usize>() -> Result<String, RHDLError>
where W<ROUNDS>: BitWidth,
Emits a registered round-pipeline prefix as Verilog.

Errors

Returns an error if the specialization is invalid or RHDL cannot compile, lower, or render the synchronous circuit.