sha256

Function sha256 

pub fn sha256(message: &[u8]) -> [u8; 32]
Hashes one byte slice with the correctness-first software model.

Panics

Panics only if an in-range block cannot be produced. That would require a byte slice whose bit length exceeds SHA-256’s 64-bit length field, which cannot be backed by an addressable allocation on supported targets.